@@ -4,7 +4,7 @@ describe("Encode->decode test", () => {
     const testcases = [
         {
             input: "asdf & ÿ ü '",
-            xml: "asdf &amp; &#xFF; &#xFC; &apos;",
+            xml: "asdf &amp; &#xff; &#xfc; &apos;",
             html: "asdf &amp; &yuml; &uuml; &apos;",
         },
         {
@@ -31,6 +31,10 @@ describe("Encode->decode test", () => {
             expect(encodedHTML5).toBe(html));
         it(`should HTML5 decode ${encodedHTML5}`, () =>
             expect(entities.decodeHTML(encodedHTML5)).toBe(input));
+        it("should encode emojis", () =>
+            expect(entities.encodeHTML5("😄🍾🥳💥😇")).toBe(
+                "&#x1f604;&#x1f37e;&#x1f973;&#x1f4a5;&#x1f607;"
+            ));
     }
 
     it("should encode data URIs (issue #16)", () => {
@@ -41,9 +45,20 @@ describe("Encode->decode test", () => {
 });
 
 describe("encodeNonAsciiHTML", () => {
-    it("should encode all non-ASCII characters", () => {
+    it("should encode all non-ASCII characters", () =>
         expect(entities.encodeNonAsciiHTML("<test> #123! übermaßen")).toBe(
             "&lt;test&gt; #123! &uuml;berma&szlig;en"
-        );
-    });
+        ));
+
+    it("should encode emojis", () =>
+        expect(entities.encodeNonAsciiHTML("😄🍾🥳💥😇")).toBe(
+            "&#x1f604;&#x1f37e;&#x1f973;&#x1f4a5;&#x1f607;"
+        ));
+
+    it("should encode chars above surrogates", () =>
+        expect(
+            entities.encodeNonAsciiHTML("♒️♓️♈️♉️♊️♋️♌️♍️♎️♏️♐️♑️")
+        ).toBe(
+            "&#x2652;&#xfe0f;&#x2653;&#xfe0f;&#x2648;&#xfe0f;&#x2649;&#xfe0f;&#x264a;&#xfe0f;&#x264b;&#xfe0f;&#x264c;&#xfe0f;&#x264d;&#xfe0f;&#x264e;&#xfe0f;&#x264f;&#xfe0f;&#x2650;&#xfe0f;&#x2651;&#xfe0f;"
+        ));
 });
