@@ -16,6 +16,9 @@ describe("Documents", () => {
                 for (const e of Object.keys(doc)) {
                     for (let l = i; l < levels.length; l++) {
                         expect(entities.decode(`&${e};`, l)).toBe(doc[e]);
+                        expect(entities.decode(`&${e};`, { level: l })).toBe(
+                            doc[e]
+                        );
                     }
                 }
             });
@@ -26,6 +29,12 @@ describe("Documents", () => {
                 for (const e of Object.keys(doc)) {
                     for (let l = i; l < levels.length; l++) {
                         expect(entities.decodeStrict(`&${e};`, l)).toBe(doc[e]);
+                        expect(
+                            entities.decode(`&${e};`, {
+                                level: l,
+                                mode: entities.DecodingMode.Strict,
+                            })
+                        ).toBe(doc[e]);
                     }
                 }
             });
@@ -35,29 +44,42 @@ describe("Documents", () => {
             it(levels[i], () => {
                 for (const e of Object.keys(doc)) {
                     for (let l = i; l < levels.length; l++) {
-                        expect(
-                            entities.decode(entities.encode(doc[e], l), l)
-                        ).toBe(doc[e]);
+                        const encoded = entities.encode(doc[e], l);
+                        const decoded = entities.decode(encoded, l);
+                        expect(decoded).toBe(doc[e]);
                     }
                 }
             });
+
+            it("should only encode non-ASCII values if asked", () =>
+                expect(
+                    entities.encode("Great #'s of 🎁", {
+                        level: i,
+                        mode: entities.EncodingMode.ASCII,
+                    })
+                ).toBe("Great #&apos;s of &#x1f381;"));
         });
     }
 
     describe("Legacy", () => {
+        const legacyMap: Record<string, string> = legacy;
         it("should decode", () => {
-            for (const e of Object.keys(legacy)) {
-                expect(entities.decodeHTML(`&${e}`)).toBe(
-                    (legacy as Record<string, string>)[e]
-                );
+            for (const e of Object.keys(legacyMap)) {
+                expect(entities.decodeHTML(`&${e}`)).toBe(legacyMap[e]);
+                expect(
+                    entities.decodeStrict(`&${e}`, {
+                        level: entities.EntityLevel.HTML,
+                        mode: entities.DecodingMode.Legacy,
+                    })
+                ).toBe(legacyMap[e]);
             }
         });
     });
 });
 
 const astral = [
-    ["1D306", "\uD834\uDF06"],
-    ["1D11E", "\uD834\uDD1E"],
+    ["1d306", "\uD834\uDF06"],
+    ["1d11e", "\uD834\uDD1E"],
 ];
 
 const astralSpecial = [
@@ -92,5 +114,5 @@ describe("Escape", () => {
     });
 
     it("should keep UTF8 characters", () =>
-        expect(entities.escapeUTF8('ß < "ü"')).toBe(`ß &#x3C; &#x22;ü&#x22;`));
+        expect(entities.escapeUTF8('ß < "ü"')).toBe(`ß &lt; &quot;ü&quot;`));
 });
